@@ -132,6 +132,7 @@ class WorkerCore(ABC):
             self.destinationClass.add_arguments(parser)
         if self.cacheKind:
             self.cacheClass.add_arguments(parser)
+        self.messageClass.add_arguments(parser)
         self.add_arguments(parser)
 
     def add_arguments(self, parser):
@@ -152,19 +153,20 @@ class Generator(WorkerCore):
 
     def generate(self):
         """a generator to generate dict."""
-        yield self.messageClass()
+        yield self.options.message(config=self.options)
 
     def _step(self):
         if not self.generator:
             self.generator = self.generate()
         dct = next(self.generator)
-        msg = self.messageClass({})
+        msg = self.messageClass({}, config=self.options)
         msg.update(dct)
         msg.update_version(self.name, self.version)
         self.logger.info("Generated %s", msg)
         if msg.is_valid():
             self.logger.info("Writing %s", msg)
-            self.destination.write(msg)
+            msgSize = self.destination.write(msg)
+            self.logger.info(f"Message size: {msgSize}")
             self.monitor.record_write(self.destination.topic)
         elif msg.terminated:
             self.logger.info("Message terminates here")
@@ -249,7 +251,8 @@ class Splitter(WorkerCore):
                 self.logger.info(
                     "Writing message %s to topic <%s>", str(msg), topic
                 )
-                destination.write(msg)
+                msgSize = destination.write(msg)
+                self.logger.info(f"Message size: {msgSize}")
             else:
                 self.logger.error("Produced message is invalid, skipping")
                 self.logger.error(msg.log_info())
@@ -385,7 +388,8 @@ class Processor(WorkerCore):
         elif not any((failedOnError, self.has_no_output())):
             if msg.is_valid():
                 self.logger.info("Writing message '%s'", str(msg))
-                self.destination.write(msg)
+                msgSize = self.destination.write(msg)
+                self.logger.info(f"Message size: {msgSize}")
                 self.monitor.record_write(self.destination.topic)
             else:
                 failedOnError = True
